# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/torch_snippets/',
                'doc_host': 'https://sizhky.github.io',
                'git_url': 'https://github.com/sizhky/torch_snippets/tree/master/',
                'lib_path': 'torch_snippets'},
  'syms': { 'torch_snippets.adapters': { 'torch_snippets.adapters._cvat_ann_2_csv': ( 'adapters.html#_cvat_ann_2_csv',
                                                                                      'torch_snippets/adapters.py'),
                                         'torch_snippets.adapters._get_attribute_columns': ( 'adapters.html#_get_attribute_columns',
                                                                                             'torch_snippets/adapters.py'),
                                         'torch_snippets.adapters._get_attribute_data': ( 'adapters.html#_get_attribute_data',
                                                                                          'torch_snippets/adapters.py'),
                                         'torch_snippets.adapters._process': ('adapters.html#_process', 'torch_snippets/adapters.py'),
                                         'torch_snippets.adapters.b64_2_file': ('adapters.html#b64_2_file', 'torch_snippets/adapters.py'),
                                         'torch_snippets.adapters.b64_2_np': ('adapters.html#b64_2_np', 'torch_snippets/adapters.py'),
                                         'torch_snippets.adapters.bytes_2_file': ( 'adapters.html#bytes_2_file',
                                                                                   'torch_snippets/adapters.py'),
                                         'torch_snippets.adapters.csvs_2_cvat': ('adapters.html#csvs_2_cvat', 'torch_snippets/adapters.py'),
                                         'torch_snippets.adapters.cvat_2_csvs': ('adapters.html#cvat_2_csvs', 'torch_snippets/adapters.py'),
                                         'torch_snippets.adapters.file_2_bytes': ( 'adapters.html#file_2_bytes',
                                                                                   'torch_snippets/adapters.py'),
                                         'torch_snippets.adapters.np_2_b64': ('adapters.html#np_2_b64', 'torch_snippets/adapters.py')},
            'torch_snippets.bb_utils': { 'torch_snippets.bb_utils.BB': ('bounding_boxes.html#bb', 'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.BB.__add__': ( 'bounding_boxes.html#bb.__add__',
                                                                                 'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.BB.__eq__': ( 'bounding_boxes.html#bb.__eq__',
                                                                                'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.BB.__getitem__': ( 'bounding_boxes.html#bb.__getitem__',
                                                                                     'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.BB.__hash__': ( 'bounding_boxes.html#bb.__hash__',
                                                                                  'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.BB.__init__': ( 'bounding_boxes.html#bb.__init__',
                                                                                  'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.BB.__len__': ( 'bounding_boxes.html#bb.__len__',
                                                                                 'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.BB.__repr__': ( 'bounding_boxes.html#bb.__repr__',
                                                                                  'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.BB.absolute': ( 'bounding_boxes.html#bb.absolute',
                                                                                  'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.BB.add_padding': ( 'bounding_boxes.html#bb.add_padding',
                                                                                     'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.BB.distances': ( 'bounding_boxes.html#bb.distances',
                                                                                   'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.BB.jitter': ( 'bounding_boxes.html#bb.jitter',
                                                                                'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.BB.l2': ('bounding_boxes.html#bb.l2', 'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.BB.local_to': ( 'bounding_boxes.html#bb.local_to',
                                                                                  'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.BB.relative': ( 'bounding_boxes.html#bb.relative',
                                                                                  'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.BB.remap': ('bounding_boxes.html#bb.remap', 'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.BB.shrink_inplace': ( 'bounding_boxes.html#bb.shrink_inplace',
                                                                                        'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.bbfy': ('bounding_boxes.html#bbfy', 'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.bbs2df': ('bounding_boxes.html#bbs2df', 'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.combine_xyXY_to_bb': ( 'bounding_boxes.html#combine_xyxy_to_bb',
                                                                                         'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.compute_distance_matrix': ( 'bounding_boxes.html#compute_distance_matrix',
                                                                                              'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.compute_distances': ( 'bounding_boxes.html#compute_distances',
                                                                                        'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.compute_eps': ( 'bounding_boxes.html#compute_eps',
                                                                                  'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.df2bbs': ('bounding_boxes.html#df2bbs', 'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.enlarge_bbs': ( 'bounding_boxes.html#enlarge_bbs',
                                                                                  'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.iou': ('bounding_boxes.html#iou', 'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.is_absolute': ( 'bounding_boxes.html#is_absolute',
                                                                                  'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.is_relative': ( 'bounding_boxes.html#is_relative',
                                                                                  'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.isin': ('bounding_boxes.html#isin', 'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.jitter': ('bounding_boxes.html#jitter', 'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.merge_by_bb': ( 'bounding_boxes.html#merge_by_bb',
                                                                                  'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.shrink_bbs': ( 'bounding_boxes.html#shrink_bbs',
                                                                                 'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.split_bb_to_xyXY': ( 'bounding_boxes.html#split_bb_to_xyxy',
                                                                                       'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.to_absolute': ( 'bounding_boxes.html#to_absolute',
                                                                                  'torch_snippets/bb_utils.py'),
                                         'torch_snippets.bb_utils.to_relative': ( 'bounding_boxes.html#to_relative',
                                                                                  'torch_snippets/bb_utils.py')},
            'torch_snippets.bokeh_loader': { 'torch_snippets.bokeh_loader.get_bplot': ( 'bokeh_plotting.html#get_bplot',
                                                                                        'torch_snippets/bokeh_loader.py'),
                                             'torch_snippets.bokeh_loader.parse_sz': ( 'bokeh_plotting.html#parse_sz',
                                                                                       'torch_snippets/bokeh_loader.py')},
            'torch_snippets.charts': { 'torch_snippets.charts.confusion_matrix': ( 'charts.html#confusion_matrix',
                                                                                   'torch_snippets/charts.py')},
            'torch_snippets.dates': {},
            'torch_snippets.decorators': { 'torch_snippets.decorators.check_kwargs_not_none': ( 'decorators.html#check_kwargs_not_none',
                                                                                                'torch_snippets/decorators.py'),
                                           'torch_snippets.decorators.io': ('decorators.html#io', 'torch_snippets/decorators.py'),
                                           'torch_snippets.decorators.timeit': ('decorators.html#timeit', 'torch_snippets/decorators.py')},
            'torch_snippets.fastcores': {},
            'torch_snippets.icecream': {},
            'torch_snippets.imgaug_loader': { 'torch_snippets.imgaug_loader.bbs2imgaugbbs': ( 'imgaug_loader.html#bbs2imgaugbbs',
                                                                                              'torch_snippets/imgaug_loader.py'),
                                              'torch_snippets.imgaug_loader.bw': ( 'imgaug_loader.html#bw',
                                                                                   'torch_snippets/imgaug_loader.py'),
                                              'torch_snippets.imgaug_loader.crop': ( 'imgaug_loader.html#crop',
                                                                                     'torch_snippets/imgaug_loader.py'),
                                              'torch_snippets.imgaug_loader.do': ( 'imgaug_loader.html#do',
                                                                                   'torch_snippets/imgaug_loader.py'),
                                              'torch_snippets.imgaug_loader.get_size': ( 'imgaug_loader.html#get_size',
                                                                                         'torch_snippets/imgaug_loader.py'),
                                              'torch_snippets.imgaug_loader.imgaugbbs2bbs': ( 'imgaug_loader.html#imgaugbbs2bbs',
                                                                                              'torch_snippets/imgaug_loader.py'),
                                              'torch_snippets.imgaug_loader.pad': ( 'imgaug_loader.html#pad',
                                                                                    'torch_snippets/imgaug_loader.py'),
                                              'torch_snippets.imgaug_loader.rescale': ( 'imgaug_loader.html#rescale',
                                                                                        'torch_snippets/imgaug_loader.py'),
                                              'torch_snippets.imgaug_loader.rotate': ( 'imgaug_loader.html#rotate',
                                                                                       'torch_snippets/imgaug_loader.py')},
            'torch_snippets.inspector': {'torch_snippets.inspector.inspect': ('inspector.html#inspect', 'torch_snippets/inspector.py')},
            'torch_snippets.interactive_show': { 'torch_snippets.interactive_show.convert_to_nx': ( 'interactive_show.html#convert_to_nx',
                                                                                                    'torch_snippets/interactive_show.py'),
                                                 'torch_snippets.interactive_show.df2graph_nodes': ( 'interactive_show.html#df2graph_nodes',
                                                                                                     'torch_snippets/interactive_show.py'),
                                                 'torch_snippets.interactive_show.ishow': ( 'interactive_show.html#ishow',
                                                                                            'torch_snippets/interactive_show.py'),
                                                 'torch_snippets.interactive_show.plot_graph': ( 'interactive_show.html#plot_graph',
                                                                                                 'torch_snippets/interactive_show.py'),
                                                 'torch_snippets.interactive_show.plot_image': ( 'interactive_show.html#plot_image',
                                                                                                 'torch_snippets/interactive_show.py'),
                                                 'torch_snippets.interactive_show.to_networkx': ( 'interactive_show.html#to_networkx',
                                                                                                  'torch_snippets/interactive_show.py'),
                                                 'torch_snippets.interactive_show.tolist': ( 'interactive_show.html#tolist',
                                                                                             'torch_snippets/interactive_show.py'),
                                                 'torch_snippets.interactive_show.tonp': ( 'interactive_show.html#tonp',
                                                                                           'torch_snippets/interactive_show.py'),
                                                 'torch_snippets.interactive_show.viz2': ( 'interactive_show.html#viz2',
                                                                                           'torch_snippets/interactive_show.py')},
            'torch_snippets.ipython': { 'torch_snippets.ipython.backup_all_notebooks': ( 'jupyter_notebook.html#backup_all_notebooks',
                                                                                         'torch_snippets/ipython.py'),
                                        'torch_snippets.ipython.backup_this_notebook': ( 'jupyter_notebook.html#backup_this_notebook',
                                                                                         'torch_snippets/ipython.py'),
                                        'torch_snippets.ipython.display_dfs_side_by_side': ( 'jupyter_notebook.html#display_dfs_side_by_side',
                                                                                             'torch_snippets/ipython.py'),
                                        'torch_snippets.ipython.h1': ('jupyter_notebook.html#h1', 'torch_snippets/ipython.py'),
                                        'torch_snippets.ipython.h2': ('jupyter_notebook.html#h2', 'torch_snippets/ipython.py'),
                                        'torch_snippets.ipython.h3': ('jupyter_notebook.html#h3', 'torch_snippets/ipython.py'),
                                        'torch_snippets.ipython.h4': ('jupyter_notebook.html#h4', 'torch_snippets/ipython.py'),
                                        'torch_snippets.ipython.h5': ('jupyter_notebook.html#h5', 'torch_snippets/ipython.py'),
                                        'torch_snippets.ipython.h6': ('jupyter_notebook.html#h6', 'torch_snippets/ipython.py'),
                                        'torch_snippets.ipython.is_in_notebook': ( 'jupyter_notebook.html#is_in_notebook',
                                                                                   'torch_snippets/ipython.py'),
                                        'torch_snippets.ipython.save_notebook': ( 'jupyter_notebook.html#save_notebook',
                                                                                  'torch_snippets/ipython.py'),
                                        'torch_snippets.ipython.show_big_dataframe': ( 'jupyter_notebook.html#show_big_dataframe',
                                                                                       'torch_snippets/ipython.py'),
                                        'torch_snippets.ipython.shutdown_current_notebook': ( 'jupyter_notebook.html#shutdown_current_notebook',
                                                                                              'torch_snippets/ipython.py')},
            'torch_snippets.load_defaults': { 'torch_snippets.load_defaults.exists': ( 'load_defautls.html#exists',
                                                                                       'torch_snippets/load_defaults.py'),
                                              'torch_snippets.load_defaults.loadifexists': ( 'load_defautls.html#loadifexists',
                                                                                             'torch_snippets/load_defaults.py')},
            'torch_snippets.loader': {},
            'torch_snippets.logger': { 'torch_snippets.logger.RichHandler.render': ( 'logging.html#richhandler.render',
                                                                                     'torch_snippets/logger.py'),
                                       'torch_snippets.logger.enter_exit': ('logging.html#enter_exit', 'torch_snippets/logger.py'),
                                       'torch_snippets.logger.get_console': ('logging.html#get_console', 'torch_snippets/logger.py'),
                                       'torch_snippets.logger.get_logger_level': ( 'logging.html#get_logger_level',
                                                                                   'torch_snippets/logger.py'),
                                       'torch_snippets.logger.in_logger_mode': ('logging.html#in_logger_mode', 'torch_snippets/logger.py'),
                                       'torch_snippets.logger.logger_mode': ('logging.html#logger_mode', 'torch_snippets/logger.py'),
                                       'torch_snippets.logger.notify_waiting': ('logging.html#notify_waiting', 'torch_snippets/logger.py'),
                                       'torch_snippets.logger.reset_logger': ('logging.html#reset_logger', 'torch_snippets/logger.py')},
            'torch_snippets.markup': { 'torch_snippets.markup.AttrDict': ('markups.html#attrdict', 'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.__contains__': ( 'markups.html#attrdict.__contains__',
                                                                                        'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.__delitem__': ( 'markups.html#attrdict.__delitem__',
                                                                                       'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.__dir__': ( 'markups.html#attrdict.__dir__',
                                                                                   'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.__eq__': ( 'markups.html#attrdict.__eq__',
                                                                                  'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.__init__': ( 'markups.html#attrdict.__init__',
                                                                                    'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.__iter__': ( 'markups.html#attrdict.__iter__',
                                                                                    'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.__len__': ( 'markups.html#attrdict.__len__',
                                                                                   'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.__repr__': ( 'markups.html#attrdict.__repr__',
                                                                                    'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict._wrap': ('markups.html#attrdict._wrap', 'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.drop': ('markups.html#attrdict.drop', 'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.fetch': ('markups.html#attrdict.fetch', 'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.find_address': ( 'markups.html#attrdict.find_address',
                                                                                        'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.get': ('markups.html#attrdict.get', 'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.items': ('markups.html#attrdict.items', 'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.keys': ('markups.html#attrdict.keys', 'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.map': ('markups.html#attrdict.map', 'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.pretty': ( 'markups.html#attrdict.pretty',
                                                                                  'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.summary': ( 'markups.html#attrdict.summary',
                                                                                   'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.to_dict': ( 'markups.html#attrdict.to_dict',
                                                                                   'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.update': ( 'markups.html#attrdict.update',
                                                                                  'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.values': ( 'markups.html#attrdict.values',
                                                                                  'torch_snippets/markup.py'),
                                       'torch_snippets.markup.AttrDict.write_summary': ( 'markups.html#attrdict.write_summary',
                                                                                         'torch_snippets/markup.py'),
                                       'torch_snippets.markup._default': ('markups.html#_default', 'torch_snippets/markup.py'),
                                       'torch_snippets.markup.isnamedtupleinstance': ( 'markups.html#isnamedtupleinstance',
                                                                                       'torch_snippets/markup.py'),
                                       'torch_snippets.markup.pretty_json': ('markups.html#pretty_json', 'torch_snippets/markup.py'),
                                       'torch_snippets.markup.read_json': ('markups.html#read_json', 'torch_snippets/markup.py'),
                                       'torch_snippets.markup.read_jsonl': ('markups.html#read_jsonl', 'torch_snippets/markup.py'),
                                       'torch_snippets.markup.read_xml': ('markups.html#read_xml', 'torch_snippets/markup.py'),
                                       'torch_snippets.markup.read_yaml': ('markups.html#read_yaml', 'torch_snippets/markup.py'),
                                       'torch_snippets.markup.unpack': ('markups.html#unpack', 'torch_snippets/markup.py'),
                                       'torch_snippets.markup.write_json': ('markups.html#write_json', 'torch_snippets/markup.py'),
                                       'torch_snippets.markup.write_jsonl': ('markups.html#write_jsonl', 'torch_snippets/markup.py'),
                                       'torch_snippets.markup.write_xml': ('markups.html#write_xml', 'torch_snippets/markup.py'),
                                       'torch_snippets.markup.write_yaml': ('markups.html#write_yaml', 'torch_snippets/markup.py')},
            'torch_snippets.markup2': { 'torch_snippets.markup2.AttrDict': ('markups.html#attrdict', 'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.__contains__': ( 'markups.html#attrdict.__contains__',
                                                                                          'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.__delitem__': ( 'markups.html#attrdict.__delitem__',
                                                                                         'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.__dir__': ( 'markups.html#attrdict.__dir__',
                                                                                     'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.__eq__': ( 'markups.html#attrdict.__eq__',
                                                                                    'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.__init__': ( 'markups.html#attrdict.__init__',
                                                                                      'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.__iter__': ( 'markups.html#attrdict.__iter__',
                                                                                      'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.__len__': ( 'markups.html#attrdict.__len__',
                                                                                     'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.__repr__': ( 'markups.html#attrdict.__repr__',
                                                                                      'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict._wrap': ( 'markups.html#attrdict._wrap',
                                                                                   'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.drop': ('markups.html#attrdict.drop', 'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.fetch': ( 'markups.html#attrdict.fetch',
                                                                                   'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.find_address': ( 'markups.html#attrdict.find_address',
                                                                                          'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.get': ('markups.html#attrdict.get', 'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.items': ( 'markups.html#attrdict.items',
                                                                                   'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.keys': ('markups.html#attrdict.keys', 'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.map': ('markups.html#attrdict.map', 'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.pretty': ( 'markups.html#attrdict.pretty',
                                                                                    'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.print_summary': ( 'markups.html#attrdict.print_summary',
                                                                                           'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.summary': ( 'markups.html#attrdict.summary',
                                                                                     'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.to_dict': ( 'markups.html#attrdict.to_dict',
                                                                                     'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.update': ( 'markups.html#attrdict.update',
                                                                                    'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.values': ( 'markups.html#attrdict.values',
                                                                                    'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.AttrDict.write_summary': ( 'markups.html#attrdict.write_summary',
                                                                                           'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2._default': ('markups.html#_default', 'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.hash_tensor': ('markups.html#hash_tensor', 'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.isnamedtupleinstance': ( 'markups.html#isnamedtupleinstance',
                                                                                         'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.pretty_json': ('markups.html#pretty_json', 'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.read_json': ('markups.html#read_json', 'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.read_jsonl': ('markups.html#read_jsonl', 'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.read_xml': ('markups.html#read_xml', 'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.read_yaml': ('markups.html#read_yaml', 'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.unpack': ('markups.html#unpack', 'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.write_json': ('markups.html#write_json', 'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.write_jsonl': ('markups.html#write_jsonl', 'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.write_xml': ('markups.html#write_xml', 'torch_snippets/markup2.py'),
                                        'torch_snippets.markup2.write_yaml': ('markups.html#write_yaml', 'torch_snippets/markup2.py')},
            'torch_snippets.misc': { 'torch_snippets.misc.Timer': ('misc.html#timer', 'torch_snippets/misc.py'),
                                     'torch_snippets.misc.Timer.__call__': ('misc.html#timer.__call__', 'torch_snippets/misc.py'),
                                     'torch_snippets.misc.Timer.__init__': ('misc.html#timer.__init__', 'torch_snippets/misc.py'),
                                     'torch_snippets.misc.io': ('misc.html#io', 'torch_snippets/misc.py'),
                                     'torch_snippets.misc.timeit': ('misc.html#timeit', 'torch_snippets/misc.py'),
                                     'torch_snippets.misc.track2': ('misc.html#track2', 'torch_snippets/misc.py')},
            'torch_snippets.paths': { 'torch_snippets.paths.Glob': ('paths.html#glob', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.P.Glob': ('paths.html#p.glob', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.P.cp': ('paths.html#p.cp', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.P.extn': ('paths.html#p.extn', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.P.mv': ('paths.html#p.mv', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.P.read_lines': ('paths.html#p.read_lines', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.P.rm': ('paths.html#p.rm', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.P.rmtree': ('paths.html#p.rmtree', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.P.sample': ('paths.html#p.sample', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.P.size': ('paths.html#p.size', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.P.write_lines': ('paths.html#p.write_lines', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.common_items': ('paths.html#common_items', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.dumpdill': ('paths.html#dumpdill', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.extn': ('paths.html#extn', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.find': ('paths.html#find', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.fname': ('paths.html#fname', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.fname2': ('paths.html#fname2', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.folder_summary': ('paths.html#folder_summary', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.input_to_str': ('paths.html#input_to_str', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.isdir': ('paths.html#isdir', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.list_zip': ('paths.html#list_zip', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.loaddill': ('paths.html#loaddill', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.makedir': ('paths.html#makedir', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.md5': ('paths.html#md5', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.output_to_path': ('paths.html#output_to_path', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.parent': ('paths.html#parent', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.readlines': ('paths.html#readlines', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.remove_duplicates': ('paths.html#remove_duplicates', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.rename_batch': ('paths.html#rename_batch', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.stem': ('paths.html#stem', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.stems': ('paths.html#stems', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.unzip_file': ('paths.html#unzip_file', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.writelines': ('paths.html#writelines', 'torch_snippets/paths.py'),
                                      'torch_snippets.paths.zip_files': ('paths.html#zip_files', 'torch_snippets/paths.py')},
            'torch_snippets.pdf_loader': { 'torch_snippets.pdf_loader.PDF': ('pdf.html#pdf', 'torch_snippets/pdf_loader.py'),
                                           'torch_snippets.pdf_loader.PDF.__getitem__': ( 'pdf.html#pdf.__getitem__',
                                                                                          'torch_snippets/pdf_loader.py'),
                                           'torch_snippets.pdf_loader.PDF.__init__': ( 'pdf.html#pdf.__init__',
                                                                                       'torch_snippets/pdf_loader.py'),
                                           'torch_snippets.pdf_loader.PDF.__len__': ( 'pdf.html#pdf.__len__',
                                                                                      'torch_snippets/pdf_loader.py'),
                                           'torch_snippets.pdf_loader.PDF.get_image': ( 'pdf.html#pdf.get_image',
                                                                                        'torch_snippets/pdf_loader.py'),
                                           'torch_snippets.pdf_loader.PDF.show': ('pdf.html#pdf.show', 'torch_snippets/pdf_loader.py')},
            'torch_snippets.registry': { 'torch_snippets.registry.parse': ('registry.html#parse', 'torch_snippets/registry.py'),
                                         'torch_snippets.registry.parse_and_resolve': ( 'registry.html#parse_and_resolve',
                                                                                        'torch_snippets/registry.py'),
                                         'torch_snippets.registry.parse_string': ( 'registry.html#parse_string',
                                                                                   'torch_snippets/registry.py'),
                                         'torch_snippets.registry.tryeval': ('registry.html#tryeval', 'torch_snippets/registry.py')},
            'torch_snippets.sklegos': { 'torch_snippets.sklegos.Cat2Num': ('sklegos.html#cat2num', 'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.Cat2Num.__init__': ( 'sklegos.html#cat2num.__init__',
                                                                                     'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.Cat2Num.fit': ('sklegos.html#cat2num.fit', 'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.Cat2Num.fit_transform': ( 'sklegos.html#cat2num.fit_transform',
                                                                                          'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.Cat2Num.transform': ( 'sklegos.html#cat2num.transform',
                                                                                      'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.GroupedEstimator.transform': ( 'sklegos.html#groupedestimator.transform',
                                                                                               'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.GroupedPredictor.transform': ( 'sklegos.html#groupedpredictor.transform',
                                                                                               'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.ImputeMissingValues': ( 'sklegos.html#imputemissingvalues',
                                                                                        'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.ImputeMissingValues.__init__': ( 'sklegos.html#imputemissingvalues.__init__',
                                                                                                 'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.ImputeMissingValues.fit': ( 'sklegos.html#imputemissingvalues.fit',
                                                                                            'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.ImputeMissingValues.fit_transform': ( 'sklegos.html#imputemissingvalues.fit_transform',
                                                                                                      'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.ImputeMissingValues.transform': ( 'sklegos.html#imputemissingvalues.transform',
                                                                                                  'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.LambdaTransformer': ( 'sklegos.html#lambdatransformer',
                                                                                      'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.LambdaTransformer.__init__': ( 'sklegos.html#lambdatransformer.__init__',
                                                                                               'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.LambdaTransformer.fit': ( 'sklegos.html#lambdatransformer.fit',
                                                                                          'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.LambdaTransformer.fit_transform': ( 'sklegos.html#lambdatransformer.fit_transform',
                                                                                                    'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.LambdaTransformer.predict': ( 'sklegos.html#lambdatransformer.predict',
                                                                                              'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.LambdaTransformer.predict_proba': ( 'sklegos.html#lambdatransformer.predict_proba',
                                                                                                    'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.LambdaTransformer.transform': ( 'sklegos.html#lambdatransformer.transform',
                                                                                                'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.MakeFrame': ('sklegos.html#makeframe', 'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.MakeFrame.__init__': ( 'sklegos.html#makeframe.__init__',
                                                                                       'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.MakeFrame.fit': ('sklegos.html#makeframe.fit', 'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.MakeFrame.predict': ( 'sklegos.html#makeframe.predict',
                                                                                      'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.MakeFrame.predict_proba': ( 'sklegos.html#makeframe.predict_proba',
                                                                                            'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.MakeFrame.transform': ( 'sklegos.html#makeframe.transform',
                                                                                        'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.SplitDateColumn': ( 'sklegos.html#splitdatecolumn',
                                                                                    'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.SplitDateColumn.__init__': ( 'sklegos.html#splitdatecolumn.__init__',
                                                                                             'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.SplitDateColumn.fit': ( 'sklegos.html#splitdatecolumn.fit',
                                                                                        'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.SplitDateColumn.predict': ( 'sklegos.html#splitdatecolumn.predict',
                                                                                            'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.SplitDateColumn.predict_proba': ( 'sklegos.html#splitdatecolumn.predict_proba',
                                                                                                  'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.SplitDateColumn.transform': ( 'sklegos.html#splitdatecolumn.transform',
                                                                                              'torch_snippets/sklegos.py'),
                                        'torch_snippets.sklegos.train_test_split': ( 'sklegos.html#train_test_split',
                                                                                     'torch_snippets/sklegos.py')},
            'torch_snippets.text_utils': {},
            'torch_snippets.thinc_parser.parser': {},
            'torch_snippets.torch_loader': {},
            'torch_snippets.trainer.capsule': { 'torch_snippets.trainer.capsule.Capsule': ( 'capsule.html#capsule',
                                                                                            'torch_snippets/trainer/capsule.py'),
                                                'torch_snippets.trainer.capsule.Capsule.__init__': ( 'capsule.html#capsule.__init__',
                                                                                                     'torch_snippets/trainer/capsule.py'),
                                                'torch_snippets.trainer.capsule.Capsule.after_predict': ( 'capsule.html#capsule.after_predict',
                                                                                                          'torch_snippets/trainer/capsule.py'),
                                                'torch_snippets.trainer.capsule.Capsule.after_train_batch': ( 'capsule.html#capsule.after_train_batch',
                                                                                                              'torch_snippets/trainer/capsule.py'),
                                                'torch_snippets.trainer.capsule.Capsule.after_validate_batch': ( 'capsule.html#capsule.after_validate_batch',
                                                                                                                 'torch_snippets/trainer/capsule.py'),
                                                'torch_snippets.trainer.capsule.Capsule.before_predict': ( 'capsule.html#capsule.before_predict',
                                                                                                           'torch_snippets/trainer/capsule.py'),
                                                'torch_snippets.trainer.capsule.Capsule.before_train_batch': ( 'capsule.html#capsule.before_train_batch',
                                                                                                               'torch_snippets/trainer/capsule.py'),
                                                'torch_snippets.trainer.capsule.Capsule.before_validate_batch': ( 'capsule.html#capsule.before_validate_batch',
                                                                                                                  'torch_snippets/trainer/capsule.py'),
                                                'torch_snippets.trainer.capsule.Capsule.evaluate': ( 'capsule.html#capsule.evaluate',
                                                                                                     'torch_snippets/trainer/capsule.py'),
                                                'torch_snippets.trainer.capsule.Capsule.fit': ( 'capsule.html#capsule.fit',
                                                                                                'torch_snippets/trainer/capsule.py'),
                                                'torch_snippets.trainer.capsule.Capsule.load': ( 'capsule.html#capsule.load',
                                                                                                 'torch_snippets/trainer/capsule.py'),
                                                'torch_snippets.trainer.capsule.Capsule.predict_batch': ( 'capsule.html#capsule.predict_batch',
                                                                                                          'torch_snippets/trainer/capsule.py'),
                                                'torch_snippets.trainer.capsule.Capsule.save': ( 'capsule.html#capsule.save',
                                                                                                 'torch_snippets/trainer/capsule.py'),
                                                'torch_snippets.trainer.capsule.Capsule.train_batch': ( 'capsule.html#capsule.train_batch',
                                                                                                        'torch_snippets/trainer/capsule.py'),
                                                'torch_snippets.trainer.capsule.Capsule.validate_batch': ( 'capsule.html#capsule.validate_batch',
                                                                                                           'torch_snippets/trainer/capsule.py'),
                                                'torch_snippets.trainer.capsule.predict': ( 'capsule.html#predict',
                                                                                            'torch_snippets/trainer/capsule.py'),
                                                'torch_snippets.trainer.capsule.to': ( 'capsule.html#to',
                                                                                       'torch_snippets/trainer/capsule.py'),
                                                'torch_snippets.trainer.capsule.train': ( 'capsule.html#train',
                                                                                          'torch_snippets/trainer/capsule.py'),
                                                'torch_snippets.trainer.capsule.validate': ( 'capsule.html#validate',
                                                                                             'torch_snippets/trainer/capsule.py')},
            'torch_snippets.trainer.config': { 'torch_snippets.trainer.config.DeepLearningConfig': ( 'config.html#deeplearningconfig',
                                                                                                     'torch_snippets/trainer/config.py'),
                                               'torch_snippets.trainer.config.DeepLearningConfig.__contains__': ( 'config.html#deeplearningconfig.__contains__',
                                                                                                                  'torch_snippets/trainer/config.py'),
                                               'torch_snippets.trainer.config.DeepLearningConfig.__getitem__': ( 'config.html#deeplearningconfig.__getitem__',
                                                                                                                 'torch_snippets/trainer/config.py'),
                                               'torch_snippets.trainer.config.DeepLearningConfig.__repr__': ( 'config.html#deeplearningconfig.__repr__',
                                                                                                              'torch_snippets/trainer/config.py'),
                                               'torch_snippets.trainer.config.DeepLearningConfig.from_ini_file': ( 'config.html#deeplearningconfig.from_ini_file',
                                                                                                                   'torch_snippets/trainer/config.py'),
                                               'torch_snippets.trainer.config.DeepLearningConfig.keys': ( 'config.html#deeplearningconfig.keys',
                                                                                                          'torch_snippets/trainer/config.py'),
                                               'torch_snippets.trainer.config.GenericConfig': ( 'config.html#genericconfig',
                                                                                                'torch_snippets/trainer/config.py'),
                                               'torch_snippets.trainer.config.GenericConfig.__init__': ( 'config.html#genericconfig.__init__',
                                                                                                         'torch_snippets/trainer/config.py'),
                                               'torch_snippets.trainer.config.GenericConfig.from_ini_file': ( 'config.html#genericconfig.from_ini_file',
                                                                                                              'torch_snippets/trainer/config.py')},
            'torch_snippets.trainer.hooks': {}}}
